package com.caimei365.user.components;

import com.caimei365.user.mapper.BaseMapper;
import com.caimei365.user.mapper.LoginMapper;
import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.vo.UserLoginVo;
import com.caimei365.user.utils.ValidateUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/26
 */
@Slf4j
@Service
public class CommonService {
    @Resource
    private RedisService redisService;
    @Resource
    private BaseMapper baseMapper;
    @Resource
    private LoginMapper loginMapper;
    /**
     * 校验邮箱
     * @param email 邮箱
     * @return errorMsg
     */
    public String emailValidate(String email) {
        if (!ValidateUtil.validateEmail(email)) {
            return  "邮箱格式不正确";
        }
        Integer userIdByEmail = baseMapper.getUserIdByEmail(email);
        if (null != userIdByEmail && userIdByEmail > 0 ) {
            return "该邮箱已被使用";
        }
        return null;
    }
    /**
     * 校验手机号与验证码
     * @param mobile 手机号
     * @param smsCode 验证码
     * @return errorMsg
     */
    public String mobileAndCodeValidate(String mobile, String smsCode) {
        ResponseJson model = ValidateUtil.validateMobile(mobile);
        if (model.getCode() == -1) {
            return model.getMsg();
        }
        if (StringUtils.isNotBlank(smsCode)){
            String redisSmsCode = (String) redisService.get("code:" + mobile);
            if (!redisSmsCode.equals(smsCode)) {
                return "手机验证码错误";
            }
        }
        boolean flag = false;
        // 查找用户表是否存在
        Integer dbUserId = baseMapper.getUserIdByMobile(mobile);
        if (null != dbUserId && dbUserId > 0) {
            UserLoginVo user = loginMapper.getLoginUserByUserId(dbUserId);
            String showName = ValidateUtil.nameConversion(user.getUserName());
            if (2 == user.getUserIdentity() || 4 == user.getUserIdentity()) {
                return "该手机号已绑定机构(" + showName + ")联系人，请重新填写手机号";
            } else if (3 == user.getUserIdentity()) {
                return "该手机号已绑定供应商(" + showName + ")联系人，请重新填写手机号";
            }
            flag = true;
        }
        // 查找运营人员表是否存在
        Integer dbOperationId = baseMapper.getOperationIdByMobile(mobile);
        if (null != dbOperationId && dbOperationId > 0) {
            UserLoginVo operation = loginMapper.getOperationUserByOperationId(dbOperationId);
            String showName = ValidateUtil.nameConversion(operation.getUserName());
            if (2 == operation.getUserIdentity() || 4 == operation.getUserIdentity()) {
                return "该手机号已绑定机构(" + showName + ")运营人员，请重新填写手机号";
            } else if (3 == operation.getUserIdentity()) {
                return "该手机号已绑定供应商(" + showName + ")运营人员，请重新填写手机号";
            }
            flag = true;
        }
        if (flag) {
            return "该手机号已被使用";
        }
        return null;
    }
}
