package com.caimei365.user.mapper;

import com.caimei365.user.model.vo.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/10
 */
@Mapper
public interface BaseMapper {
    /**
     * 根据邮箱获取用户id
     *
     * @param email 邮箱
     * @return userId
     */
    Integer getUserIdByEmail(@Param("email") String email);

    /**
     * 根据用户Id查询用户是否存在
     * @param userId   用户Id
     * @return
     */
    Integer getUserIdByUserId(Integer userId);
    /**
     * 根据手机号获取用户Id
     *
     * @param mobile 手机号
     * @return 用户Id
     */
    Integer getUserIdByMobile(@Param("mobile") String mobile);
    /**
     * 根据运营人员手机号获用户Id
     *
     * @param mobile 手机号
     * @return 用户Id
     */
    Integer getOperationUserIdByMobile(String mobile);

    /**
     * 根据用户Id获取机构状态
     * @param userId
     * @return
     */
    Integer getClubStatusByUserId(Integer userId);
    /**
     * 根据手机号获取运营人员Id
     *
     * @param mobile 手机号
     * @return userId
     */
    Integer getOperationIdByMobile(@Param("mobile") String mobile);

    /**
     * 省
     *
     * @param provinceId
     * @return
     */
    ProvinceVo getProvince(Integer provinceId);

    /**
     * 市
     *
     * @param cityId
     * @return
     */
    CityVo getCity(Integer cityId);

    /**
     * 区
     *
     * @param townId
     * @return
     */
    TownVo getTown(Integer townId);

    /**
     * 根据用户Id获取用户信息
     * @param userId    用户Id
     * @return
     */
    UserVo getUserByUserId(Integer userId);

    /**
     * 根据用户Id获取用户名
     * @param userId    用户Id
     * @return
     */
    String getUserNameByUserId(Integer userId);

}
